@@ -9,7 +9,7 @@ except ModuleNotFoundError:
 
 from .. import base, exc
 from .._asymmetric import OAEP, PSS, MGF1
-from ._hashes import hashes as _hashes, Hash
+from ._hashes import Hash
 from ._serialization import encodings, formats, protection_schemes
 
 paddings = {
@@ -224,14 +224,15 @@ class RSAPublicKey(_RSAKey, base.BasePublicKey):
 
 def _get_padding(pad):
     _pad = paddings[pad.__class__]
-    mhash = _hashes[pad.mgf.hash]()
+    mhash = Hash(pad.mgf.hash.name,
+                 digest_size=pad.mgf.hash.digest_size)._hasher
     _mgf = lambda x, y: paddings[pad.mgf.__class__](x, y, mhash)
     return _pad, _mgf
 
 
 def _get_cipher(key, pad):
     _pad, _mgf = _get_padding(pad)
-    phash = _hashes[pad.hash]()
+    phash = Hash(pad.hash.name, digest_size=pad.hash.digest_size)._hasher
     return _pad(key, hashAlgo=phash, mgfunc=_mgf)
 
 
@@ -364,7 +365,5 @@ class RSAVerifierCtx(SigVerContext):
             raise TypeError(
                 'the message hashing object must be instantiated '
                 'from the same backend as that of the RSA key.', )
-        try:
-            return self._sig.verify(msghash._hasher, signature)
-        except ValueError as e:
+        if not self._sig.verify(msghash._hasher, signature):
             raise exc.SignatureError from e
